<?php

namespace Drupal\page_manager_search\Language;

use Drupal\Core\Language\LanguageInterface;

/**
 * Defines an interface for a service for safe language switching.
 */
interface LanguageSwitcherInterface {

  /**
   * Safely switches to another language.
   *
   * Each invocation of LanguageSwitcherInterface::switchTo() must be
   * matched by a corresponding invocation of
   * LanguageSwitcherInterface::switchBack() in the same function.
   *
   * @param \Drupal\core\Language\LanguageInterface $language
   *   The language to switch to.
   *
   * @return \Drupal\page_manager_search\Language\LanguageSwitcherInterface
   *   $this.
   */
  public function switchTo(LanguageInterface $language);

  /**
   * Reverts to a previous language after switching.
   *
   * @return \Drupal\page_manager_search\Language\LanguageSwitcherInterface
   *   $this.
   *
   * @throws \RuntimeException
   *   When there are no more language switches to revert.
   */
  public function switchBack();

}
